@@ -31,7 +31,9 @@ class JSONobject(object):
     pickler = jsonPickler()
     
     def todict(self):
-        return self.__dict__.copy()
+        d = self.__dict__.copy()
+        d.pop('pickler',None)
+        return d
     
     def tojson(self):
         return self.pickler.dumps(self.todict())
@@ -41,4 +43,5 @@ class JSONdatainfo(JSONobject):
     
     def __init__(self, data = None, info = None):
         self.data = data
-        self.info = info
\ No newline at end of file
+        self.info = info
+        
